@@ -61,15 +61,10 @@ G_BEGIN_DECLS
 #define VTE_COLOR_PLAIN_OFFSET		0
 #define VTE_COLOR_BRIGHT_OFFSET		8
 #define VTE_COLOR_DIM_OFFSET		16
-#define VTE_DEF_FG			256
-#define VTE_DEF_BG			257
-#define VTE_BOLD_FG			258
-#define VTE_DIM_FG			259
-#define VTE_DEF_HL                      260
-#define VTE_CUR_BG			261
+/* More color defines in ring.h */
 
-#define VTE_SATURATION_MAX		10000
 #define VTE_SCROLLBACK_INIT		100
+#define VTE_SATURATION_MAX		10000
 #define VTE_DEFAULT_CURSOR		GDK_XTERM
 #define VTE_MOUSING_CURSOR		GDK_LEFT_PTR
 #define VTE_TAB_MAX			999
@@ -211,8 +206,7 @@ struct _VteTerminalPrivate {
 	/* Screen data.  We support the normal screen, and an alternate
 	 * screen, which seems to be a DEC-specific feature. */
 	struct _VteScreen {
-		VteRing *row_data;	/* row data, arranged as a GArray of
-					   vte_charcell structures */
+		VteRing row_data[1];	/* buffer contents */
 		struct vte_cursor_position {
 			long row, col;
 		} cursor_current, cursor_saved;
@@ -231,17 +225,16 @@ struct _VteTerminalPrivate {
 		gboolean scrolling_restricted;
 		long scroll_delta;	/* scroll offset */
 		long insert_delta;	/* insertion offset */
-		struct vte_charcell defaults;	/* default characteristics
+		VteCell defaults;	/* default characteristics
 						   for insertion of any new
 						   characters */
-		struct vte_charcell color_defaults;	/* original defaults
+		VteCell color_defaults;	/* original defaults
 							   plus the current
 							   fore/back */
-		struct vte_charcell fill_defaults;	/* original defaults
+		VteCell fill_defaults;	/* original defaults
 							   plus the current
 							   fore/back with no
 							   character data */
-		struct vte_charcell basic_defaults;	/* original defaults */
 		gboolean alternate_charset;
 		gboolean status_line;
 		GString *status_line_contents;
@@ -340,7 +333,7 @@ struct _VteTerminalPrivate {
 	gboolean cursor_color_set;
 	struct vte_palette_entry {
 		guint16 red, green, blue;
-	} palette[VTE_CUR_BG + 1];
+	} palette[VTE_PALETTE_SIZE];
 
 	/* Mouse cursors. */
 	gboolean mouse_cursor_visible;
